type ScaleUnit = 'rem' | 'px';
type Category = 'titlepiece' | 'headline' | 'body' | 'textSans';
type LineHeight = 'tight' | 'regular' | 'loose';
type FontWeight = 'light' | 'regular' | 'medium' | 'bold';
type FontStyle = 'normal' | 'italic';
type FontWeightDefinition = {
    hasItalic: boolean;
};
type Option<A> = A | null;
type TypographyStyles = {
    fontFamily: string;
    fontSize: string | number;
    lineHeight: string | number;
    fontWeight?: number;
    fontStyle?: string;
};
type TypographySizes = {
    [key in string]: number;
};
interface TitlepieceSizes extends TypographySizes {
    small: number;
    medium: number;
    large: number;
}
interface HeadlineSizes extends TypographySizes {
    xxxsmall: number;
    xxsmall: number;
    xsmall: number;
    small: number;
    medium: number;
    large: number;
    xlarge: number;
}
interface BodySizes extends TypographySizes {
    small: number;
    medium: number;
}
interface TextSansSizes extends TypographySizes {
    xxsmall: number;
    xsmall: number;
    small: number;
    medium: number;
    large: number;
    xlarge: number;
    xxlarge: number;
    xxxlarge: number;
}
type Fs = (category: Category) => (level: string, { lineHeight, fontWeight, fontStyle, unit, }: {
    lineHeight: LineHeight;
    fontWeight: FontWeight;
    fontStyle: Option<FontStyle>;
    unit: ScaleUnit;
}) => TypographyStyles;
type FontScaleFunction = (options?: FontScaleArgs) => TypographyStyles;
type FontScaleFunctionStr = (options?: FontScaleArgs) => string;
interface FontScaleArgs {
    lineHeight?: LineHeight;
    fontWeight?: FontWeight;
    fontStyle?: FontStyle;
    unit?: ScaleUnit;
}
export { ScaleUnit, Category, LineHeight, FontWeight, FontStyle, FontWeightDefinition, Option, TypographyStyles, TypographySizes, TitlepieceSizes, HeadlineSizes, BodySizes, TextSansSizes, Fs, FontScaleFunction, FontScaleFunctionStr, FontScaleArgs };
