'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var api = require('./api.js');
var data = require('./data.js');
var objectStylesToString = require('./object-styles-to-string.js');

/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-typography--page#titlepiece) •
 * [Design System](https://theguardian.design/2a1e5182b/p/602314-typography/t/358767)
 *
 * ```
 * font-family: 'GT Guardian Titlepiece';
 * ```
 *
 * `titlepiece.small()` -> 42px
 *
 * `titlepiece.medium()` -> 50px
 *
 * `titlepiece.large()` -> 70px
 */
const titlepiece = Object.fromEntries(Object.entries(api.titlepiece).map(([key, func]) => {
    return [
        key,
        (options) => objectStylesToString.objectStylesToString(func(options)),
    ];
}));
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-typography--page#headline) •
 * [Design System](https://theguardian.design/2a1e5182b/p/602314-typography/t/7310bd)
 *
 * ```
 * font-family: 'GH Guardian Headline';
 * ```
 *
 * `headline.xxxsmall()` -> 17px
 *
 * `headline.xxsmall()` -> 20px
 *
 * `headline.xsmall()` -> 24px
 *
 * `headline.small()` -> 28px
 *
 * `headline.medium()` -> 34px
 *
 * `headline.large()` -> 42px
 *
 * `headline.xlarge()` -> 50px
 */
const headline = Object.fromEntries(Object.entries(api.headline).map(([key, func]) => {
    return [
        key,
        (options) => objectStylesToString.objectStylesToString(func(options)),
    ];
}));
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-typography--page#body) •
 * [Design System](https://theguardian.design/2a1e5182b/p/602314-typography/t/88cd8e)
 *
 * ```
 * font-family: 'GuardianTextEgyptian';
 * ```
 *
 * `body.small()` -> 15px
 *
 * `body.medium()` -> 17px
 */
const body = Object.fromEntries(Object.entries(api.body).map(([key, func]) => {
    return [
        key,
        (options) => objectStylesToString.objectStylesToString(func(options)),
    ];
}));
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-typography--page#text-sans) •
 * [Design System](https://theguardian.design/2a1e5182b/p/602314-typography/t/076605)
 *
 * ```
 * font-family: 'GuardianTextSans';
 * ```
 *
 * `textSans.xxsmall()` -> 12px
 *
 * `textSans.xsmall()` -> 14px
 *
 * `textSans.small()` -> 15px
 *
 * `textSans.medium()` -> 17px
 *
 * `textSans.large()` -> 20px
 *
 * `textSans.xlarge()` -> 24px
 *
 * `textSans.xxlarge()` -> 28px
 *
 * `textSans.xxxlarge()` -> 34px
 */
const textSans = Object.fromEntries(Object.entries(api.textSans).map(([key, func]) => {
    return [
        key,
        (options) => objectStylesToString.objectStylesToString(func(options)),
    ];
}));

exports.bodySizes = data.bodySizes;
exports.fontMapping = data.fontMapping;
exports.fontWeightMapping = data.fontWeightMapping;
exports.headlineSizes = data.headlineSizes;
exports.lineHeightMapping = data.lineHeightMapping;
exports.remBodySizes = data.remBodySizes;
exports.remHeadlineSizes = data.remHeadlineSizes;
exports.remTextSansSizes = data.remTextSansSizes;
exports.remTitlepieceSizes = data.remTitlepieceSizes;
exports.textSansSizes = data.textSansSizes;
exports.titlepieceSizes = data.titlepieceSizes;
exports.body = body;
exports.headline = headline;
exports.textSans = textSans;
exports.titlepiece = titlepiece;
//# sourceMappingURL=index.js.map
