declare type ScaleUnit = 'rem' | 'px';
declare type Category = 'titlepiece' | 'headline' | 'body' | 'textSans';
declare type LineHeight = 'tight' | 'regular' | 'loose';
declare type FontWeight = 'light' | 'regular' | 'medium' | 'bold';
declare type FontStyle = 'normal' | 'italic';
declare type FontWeightDefinition = {
    hasItalic: boolean;
};
declare type Option<A> = A | null;
declare type TypographyStyles = {
    fontFamily: string;
    fontSize: string | number;
    lineHeight: string | number;
    fontWeight?: number;
    fontStyle?: string;
};
declare type TypographySizes = {
    [key in string]: number;
};
interface TitlepieceSizes extends TypographySizes {
    small: number;
    medium: number;
    large: number;
}
interface HeadlineSizes extends TypographySizes {
    xxxsmall: number;
    xxsmall: number;
    xsmall: number;
    small: number;
    medium: number;
    large: number;
    xlarge: number;
}
interface BodySizes extends TypographySizes {
    small: number;
    medium: number;
}
interface TextSansSizes extends TypographySizes {
    xxsmall: number;
    xsmall: number;
    small: number;
    medium: number;
    large: number;
    xlarge: number;
    xxlarge: number;
    xxxlarge: number;
}
declare type Fs = (category: Category) => (level: string, { lineHeight, fontWeight, fontStyle, unit, }: {
    lineHeight: LineHeight;
    fontWeight: FontWeight;
    fontStyle: Option<FontStyle>;
    unit: ScaleUnit;
}) => TypographyStyles;
declare type FontScaleFunction = (options?: FontScaleArgs) => TypographyStyles;
declare type FontScaleFunctionStr = (options?: FontScaleArgs) => string;
interface FontScaleArgs {
    lineHeight?: LineHeight;
    fontWeight?: FontWeight;
    fontStyle?: FontStyle;
    unit?: ScaleUnit;
}

export { BodySizes, Category, FontScaleArgs, FontScaleFunction, FontScaleFunctionStr, FontStyle, FontWeight, FontWeightDefinition, Fs, HeadlineSizes, LineHeight, Option, ScaleUnit, TextSansSizes, TitlepieceSizes, TypographySizes, TypographyStyles };
